aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorluigi1111 <luigi1111w@gmail.com>2017-01-30 16:33:49 -0600
committerluigi1111 <luigi1111w@gmail.com>2017-01-30 16:33:49 -0600
commite0e2b40682814aeb9c63cd1659635d572f883f23 (patch)
tree44e7df13a15ee1f9e2a3ee3bb05ef7b79012c840
parent501560940ba96298a6d684caca27611cb63fddfe (diff)
parent7b94a47350f700fb6f8a8773bccd944fce6db24d (diff)
downloadmonzero-gui-e0e2b40682814aeb9c63cd1659635d572f883f23.tar.gz
monzero-gui-e0e2b40682814aeb9c63cd1659635d572f883f23.tar.xz
monzero-gui-e0e2b40682814aeb9c63cd1659635d572f883f23.zip
Merge branch 'path' of https://github.com/danrmiller/monero-core into danrmiller-path
-rwxr-xr-xget_libwallet_api.sh20
-rwxr-xr-xutils.sh2
2 files changed, 18 insertions, 4 deletions
diff --git a/utils.sh b/utils.sh
index ae0159ac..556cc5d3 100755
--- a/utils.sh
+++ b/utils.sh
@@ -5,6 +5,8 @@ function get_platform {
local platform="unknown"
if [ "$(uname)" == "Darwin" ]; then
platform="darwin"
+ elif [ "$(uname)" == "FreeBSD" ]; then
+ platform="freebsd"
elif [ "$(expr substr $(uname -s) 1 5)" == "Linux" ]; then
if [ "$(expr substr $(uname -m) 1 6)" == "x86_64" ]; then
platform="linux64"
diff --git a/get_libwallet_api.sh b/get_libwallet_api.sh
index d66c4c8f..1d0d9351 100755
--- a/get_libwallet_api.sh
+++ b/get_libwallet_api.sh
@@ -157,7 +157,16 @@ elif [ "$platform" == "linux32" ]; then
cmake -D CMAKE_BUILD_TYPE=$CMAKE_BUILD_TYPE -D BUILD_GUI_DEPS=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" ../..
fi
-## LINUX other (arm7 for example)
+## LINUX ARMv7
+elif [ "$platform" == "linuxarmv7" ]; then
+ echo "Configuring build for Linux armv7"
+ if [ "$STATIC" == true ]; then
+ cmake -D BUILD_TESTS=OFF -D ARCH="armv7-a" -D STATIC=ON -D BUILD_64=OFF -D BUILD_GUI_DEPS=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" ../..
+ else
+ cmake -D BUILD_TESTS=OFF -D ARCH="armv7-a" -D -D BUILD_64=OFF -D BUILD_GUI_DEPS=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" ../..
+ fi
+
+## LINUX other
elif [ "$platform" == "linux" ]; then
echo "Configuring build for Linux general"
if [ "$STATIC" == true ]; then
@@ -182,9 +191,12 @@ elif [ "$platform" == "mingw32" ]; then
cmake -D CMAKE_BUILD_TYPE=$CMAKE_BUILD_TYPE -D STATIC=ON -D Boost_DEBUG=ON -D BOOST_ROOT="$BOOST_ROOT" -D ARCH="i686" -D BUILD_64=OFF -D BUILD_GUI_DEPS=ON -D INSTALL_VENDORED_LIBUNBOUND=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" -G "MSYS Makefiles" ../..
make_exec="mingw32-make"
else
- echo "Unsupported platform: $platform"
- popd
- exit 1
+ echo "Unknown platform, configuring general build"
+ if [ "$STATIC" == true ]; then
+ cmake -D CMAKE_BUILD_TYPE=$CMAKE_BUILD_TYPE -D STATIC=ON -D BUILD_GUI_DEPS=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" ../..
+ else
+ cmake -D CMAKE_BUILD_TYPE=$CMAKE_BUILD_TYPE -D BUILD_GUI_DEPS=ON -D CMAKE_INSTALL_PREFIX="$MONERO_DIR" ../..
+ fi
fi
# set CPU core count